@@ -1,8 +1,9 @@
 """*SDK main top-level functions*."""
 from os.path import basename
 
-import iscc_core as ic
 from PIL import Image
+import iscc_core as ic
+import iscc_schema as iss
 import iscc_sdk as idk
 
 
@@ -10,15 +11,17 @@ __all__ = [
     "code_iscc",
     "code_meta",
     "code_content",
+    "code_text",
     "code_image",
     "code_audio",
+    "code_video",
     "code_data",
     "code_instance",
 ]
 
 
 def code_iscc(fp):
-    # type: (str) -> idk.IsccMeta
+    # type: (str) -> iss.IsccMeta
     """
     Generate ISCC-CODE.
 
@@ -39,18 +42,17 @@ def code_iscc(fp):
     iscc_code = ic.gen_iscc_code_v0([meta.iscc, content.iscc, data.iscc, instance.iscc])
 
     # Merge ISCC Metadata
-    iscc_meta = dict()
+    iscc_meta = dict(filename=basename(fp))
     iscc_meta.update(instance.dict())
     iscc_meta.update(data.dict())
     iscc_meta.update(content.dict())
     iscc_meta.update(meta.dict())
     iscc_meta.update(iscc_code)
-
-    return idk.IsccMeta.parse_obj(iscc_meta)
+    return iss.IsccMeta.parse_obj(iscc_meta)
 
 
 def code_meta(fp):
-    # type: (str) -> idk.IsccMeta
+    # type: (str) -> iss.IsccMeta
     """
     Generate Meta-Code from digital asset.
 
@@ -59,11 +61,8 @@ def code_meta(fp):
     :rtype: IsccMeta
     """
 
-    mediatype, mode = idk.mediatype_and_mode(fp)
+    meta = idk.extract_metadata(fp).dict()
 
-    if mode != "image":
-        raise ValueError("Unsupported mediatype: {}".format(mediatype))
-    meta = idk.image_meta_extract(fp)
     if not meta.get("name"):
         meta["name"] = idk.text_name_from_uri(fp)
 
@@ -75,12 +74,11 @@ def code_meta(fp):
     )
 
     meta.update(metacode)
-
-    return idk.IsccMeta.parse_obj(meta)
+    return iss.IsccMeta.parse_obj(meta)
 
 
 def code_content(fp):
-    # type: (str) -> idk.IsccMeta
+    # type: (str) -> iss.IsccMeta
     """
     Detect mediatype and create corresponding Content-Code.
 
@@ -88,21 +86,51 @@ def code_content(fp):
     :return: Content-Code wrapped in ISCC metadata.
     :rtype: IsccMeta
     """
+
+    schema_org_map = {
+        "text": "TextDigitalDocument",
+        "image": "ImageObject",
+        "audio": "AudioObject",
+        "video": "VideoObject",
+    }
+
     mediatype, mode = idk.mediatype_and_mode(fp)
 
     if mode == "image":
         cc = code_image(fp)
-    else:
-        raise ValueError(f"Unsupported mediatype: {mediatype}")
+    elif mode == "audio":
+        cc = code_audio(fp)
+    elif mode == "video":
+        cc = code_video(fp)
+    elif mode == "text":
+        cc = code_text(fp)
+    else:  # pragma nocover
+        raise idk.IsccUnsupportedMediatype(mediatype)
 
     cc.mediatype = mediatype
     cc.mode = mode
+    cc.type_ = schema_org_map.get(mode)
 
     return cc
 
 
+def code_text(fp):
+    """
+    Generate Content-Code Text.
+
+    :param str fp: Filepath used for Text-Code creation.
+    :return: ISCC metadata including Text-Code.
+    :rtype: IsccMeta
+    """
+    meta = idk.text_meta_extract(fp)
+    text = idk.text_extract(fp)
+    code = ic.gen_text_code_v0(text, bits=idk.sdk_opts.text_bits)
+    meta.update(code)
+    return iss.IsccMeta.parse_obj(meta)
+
+
 def code_image(fp):
-    # type: (str) -> idk.IsccMeta
+    # type: (str) -> iss.IsccMeta
     """
     Generate Content-Code Image.
 
@@ -120,28 +148,44 @@ def code_image(fp):
     code_obj = ic.gen_image_code_v0(pixels, bits=idk.sdk_opts.image_bits)
     meta.update(code_obj)
 
-    return idk.IsccMeta.parse_obj(meta)
+    return iss.IsccMeta.parse_obj(meta)
 
 
 def code_audio(fp):
-    # type: (str) -> idk.IsccMeta
+    # type: (str) -> iss.IsccMeta
     """
     Generate Content-Code Audio.
 
     :param str fp: Filepath used for Audio-Code creation.
-    :return: ISCC metadata including Image-Code.
+    :return: ISCC metadata including Audio-Code.
     :rtype: IsccMeta
     """
     meta = idk.audio_meta_extract(fp)
-    chroma = idk.audio_features_extract(fp)
-    code_obj = ic.gen_audio_code_v0(chroma["fingerprint"], bits=idk.sdk_opts.audio_bits)
+    features = idk.audio_features_extract(fp)
+    code_obj = ic.gen_audio_code_v0(features["fingerprint"], bits=idk.sdk_opts.audio_bits)
     meta.update(code_obj)
 
-    return idk.IsccMeta.parse_obj(meta)
+    return iss.IsccMeta.parse_obj(meta)
+
+
+def code_video(fp):
+    # type: (str) -> iss.IsccMeta
+    """
+    Generate Content-Code Video.
+
+    :param str fp: Filepath used for Video-Code creation.
+    :return: ISCC metadata including Image-Code.
+    :rtype: IsccMeta
+    """
+    meta = idk.video_meta_extract(fp)
+    features = idk.video_features_extract(fp)
+    code_obj = ic.gen_video_code_v0(features, bits=idk.sdk_opts.video_bits)
+    meta.update(code_obj)
+    return iss.IsccMeta.parse_obj(meta)
 
 
 def code_data(fp):
-    # type: (str) -> idk.IsccMeta
+    # type: (str) -> iss.IsccMeta
     """
     Create ISCC Data-Code.
 
@@ -155,11 +199,11 @@ def code_data(fp):
     with open(fp, "rb") as stream:
         meta = ic.gen_data_code_v0(stream, bits=idk.sdk_opts.data_bits)
 
-    return idk.IsccMeta.parse_obj(meta)
+    return iss.IsccMeta.parse_obj(meta)
 
 
 def code_instance(fp):
-    # type: (str) -> idk.IsccMeta
+    # type: (str) -> iss.IsccMeta
     """
     Create ISCC Instance-Code.
 
@@ -175,4 +219,4 @@ def code_instance(fp):
     with open(fp, "rb") as stream:
         meta = ic.gen_instance_code_v0(stream, bits=idk.sdk_opts.instance_bits)
 
-    return idk.IsccMeta.parse_obj(meta)
+    return iss.IsccMeta.parse_obj(meta)
